Crate vmaf_head_sys

Crate vmaf_head_sys 

Low-level FFI bindings to Netflix VMAF.

All functions that call into libvmaf are unsafe. Consider using a safe wrapper crate for application code.

Structs

VmafConfiguration
@struct VmafConfiguration @brief Configuration needed to initialize a VmafContext
VmafContext
VmafFeatureDictionary
VmafModel
VmafModelCollection
VmafModelCollectionScore
VmafModelCollectionScore__bindgen_ty_1
VmafModelCollectionScore__bindgen_ty_1__bindgen_ty_1
VmafModelCollectionScore__bindgen_ty_1__bindgen_ty_1__bindgen_ty_1
VmafModelConfig
VmafPicture
VmafPictureConfiguration
Picture Pool Configuration
VmafPictureConfiguration__bindgen_ty_1
VmafRef

Constants

VMAF_API_VERSION_MAJOR
VMAF_API_VERSION_MINOR
VMAF_API_VERSION_PATCH
VmafLogLevel_VMAF_LOG_LEVEL_DEBUG
VmafLogLevel_VMAF_LOG_LEVEL_ERROR
VmafLogLevel_VMAF_LOG_LEVEL_INFO
VmafLogLevel_VMAF_LOG_LEVEL_NONE
VmafLogLevel_VMAF_LOG_LEVEL_WARNING
VmafModelCollectionScoreType_VMAF_MODEL_COLLECTION_SCORE_BOOTSTRAP
VmafModelCollectionScoreType_VMAF_MODEL_COLLECTION_SCORE_UNKNOWN
VmafModelFlags_VMAF_MODEL_FLAGS_DEFAULT
VmafModelFlags_VMAF_MODEL_FLAG_DISABLE_CLIP
VmafModelFlags_VMAF_MODEL_FLAG_DISABLE_TRANSFORM
VmafModelFlags_VMAF_MODEL_FLAG_ENABLE_TRANSFORM
VmafOutputFormat_VMAF_OUTPUT_FORMAT_CSV
VmafOutputFormat_VMAF_OUTPUT_FORMAT_JSON
VmafOutputFormat_VMAF_OUTPUT_FORMAT_NONE
VmafOutputFormat_VMAF_OUTPUT_FORMAT_SUB
VmafOutputFormat_VMAF_OUTPUT_FORMAT_XML
VmafPixelFormat_VMAF_PIX_FMT_UNKNOWN
VmafPixelFormat_VMAF_PIX_FMT_YUV400P
VmafPixelFormat_VMAF_PIX_FMT_YUV420P
VmafPixelFormat_VMAF_PIX_FMT_YUV422P
VmafPixelFormat_VMAF_PIX_FMT_YUV444P
VmafPoolingMethod_VMAF_POOL_METHOD_HARMONIC_MEAN
VmafPoolingMethod_VMAF_POOL_METHOD_MAX
VmafPoolingMethod_VMAF_POOL_METHOD_MEAN
VmafPoolingMethod_VMAF_POOL_METHOD_MIN
VmafPoolingMethod_VMAF_POOL_METHOD_NB
VmafPoolingMethod_VMAF_POOL_METHOD_UNKNOWN

Functions

vmaf_close
Close a VMAF instance and free all associated memory.
vmaf_feature_dictionary_free
vmaf_feature_dictionary_set
vmaf_feature_score_at_index
Fetch feature score at specific index.
vmaf_feature_score_pooled
Pooled feature score for a specific interval.
vmaf_fetch_preallocated_picture
Fetch a preallocated picture from the picture pool. The picture must be returned to the pool via vmaf_picture_unref() when done. Pictures automatically return to the pool when their reference count reaches zero.
vmaf_import_feature_score
Import an external feature score. Useful when pre-computed feature scores are available. Also useful in the case where there is no libvmaf feature extractor implementation for a required feature.
vmaf_init
Allocate and open a VMAF instance.
vmaf_model_collection_destroy
vmaf_model_collection_feature_overload
vmaf_model_collection_load
vmaf_model_collection_load_from_path
vmaf_model_destroy
vmaf_model_feature_overload
vmaf_model_load
vmaf_model_load_from_path
vmaf_picture_alloc
vmaf_picture_unref
vmaf_preallocate_pictures
Preallocate pictures for use with multi-threaded feature extraction. Pictures are allocated once and automatically returned to the pool when fully unref’d, avoiding repeated allocation/deallocation overhead.
vmaf_read_pictures
Read a pair of pictures and queue them for eventual feature extraction. This should be called after feature extractors are registered via vmaf_use_features_from_model() and/or vmaf_use_feature(). VmafContext will take ownership of both VmafPictures (ref and dist) and vmaf_picture_unref().
vmaf_score_at_index
Predict VMAF score at specific index.
vmaf_score_at_index_model_collection
Predict VMAF score at specific index, using a model collection.
vmaf_score_pooled
Pooled VMAF score for a specific interval.
vmaf_score_pooled_model_collection
Pooled VMAF score for a specific interval, using a model collection.
vmaf_use_feature
Register specific feature extractor. Useful when a specific/additional feature is required, usually one which is not already provided by a model via vmaf_use_features_from_model(). This may be called multiple times. VmafContext will take ownership of the VmafFeatureDictionary (opts_dict). Use vmaf_feature_dictionary_free() only in the case of failure.
vmaf_use_features_from_model
Register feature extractors required by a specific VmafModel. This may be called multiple times using different models. In this case, the registered feature extractors will form a set, and any features required by multiple models will only be extracted once.
vmaf_use_features_from_model_collection
Register feature extractors required by a specific VmafModelCollection Like vmaf_use_features_from_model(), this function may be called multiple times using different model collections.
vmaf_version
Get libvmaf version.
vmaf_write_output
Write VMAF stats to an output file.

Type Aliases

VmafLogLevel
VmafModelCollectionScoreType
VmafModelFlags
VmafOutputFormat
VmafPixelFormat
VmafPoolingMethod