#[repr(C)]pub struct VmafConfiguration {
pub log_level: VmafLogLevel,
pub n_threads: c_uint,
pub n_subsample: c_uint,
pub cpumask: u64,
pub gpumask: u64,
}Expand description
@struct VmafConfiguration
@brief Configuration needed to initialize a VmafContext
@param log_level How verbose the logger is.
@param n_threads How many threads can be used to run feature extractors concurrently.
@param n_subsample Compute scores only every N frames. Note that setting an even value for N can lead to inaccurate results. For more detail, see https://github.com/Netflix/vmaf/issues/1214
@param cpumask Restrict permitted CPU instruction sets. if cpumask & 1: disable SSE2 / disable NEON (on arm64) if cpumask & 2: disable SSE3/SSSE3 if cpumask & 4: disable SSE4.1 if cpumask & 8: disable AVX2 if cpumask & 16: disable AVX512 if cpumask & 32: disable AVX512ICL
@param gpumask Restrict permitted GPU operations. if gpumask: disable CUDA
Fields
log_level: VmafLogLeveln_threads: c_uintn_subsample: c_uintcpumask: u64gpumask: u64Trait Implementations
Sourceimpl Clone for VmafConfiguration
impl Clone for VmafConfiguration
Sourcefn clone(&self) -> VmafConfiguration
fn clone(&self) -> VmafConfiguration
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more